package com.reign.gcld.yx.common;

import com.reign.framework.netty.mvc.result.ByteResult;
import com.reign.framework.netty.servlet.Request;
import com.reign.framework.netty.servlet.Session;
import com.reign.gcld.activity.service.IActivityService;
import com.reign.gcld.chat.dao.ISilenceDao;
import com.reign.gcld.chat.domain.Silence;
import com.reign.gcld.common.Constants;
import com.reign.gcld.common.Players;
import com.reign.gcld.common.TimeUtil;
import com.reign.gcld.common.Users;
import com.reign.gcld.common.log.Logger;
import com.reign.gcld.common.util.WebUtil;
import com.reign.gcld.common.web.AuthInterceptor;
import com.reign.gcld.log.ErrorLogger;
import com.reign.gcld.notice.dao.ISystemNoticeDao;
import com.reign.gcld.notice.domain.SystemNotice;
import com.reign.gcld.pay.dao.IPlayerPayDao;
import com.reign.gcld.pay.domain.PlayerPay;
import com.reign.gcld.pay.service.IPayService;
import com.reign.gcld.player.dao.IPlayerAttributeDao;
import com.reign.gcld.player.dao.IPlayerDao;
import com.reign.gcld.player.dao.IPlayerResourceDao;
import com.reign.gcld.player.dao.IPlayerTaobaoDao;
import com.reign.gcld.player.domain.Player;
import com.reign.gcld.player.domain.PlayerAttribute;
import com.reign.gcld.player.domain.PlayerTaobao;
import com.reign.gcld.player.dto.PlayerDto;
import com.reign.gcld.user.dao.IUserBlockDao;
import com.reign.gcld.user.dao.IUserDao;
import com.reign.gcld.user.domain.User;
import com.reign.gcld.user.domain.UserBlock;
import com.reign.gcld.user.dto.UserDto;
import com.reign.plugin.yx.PluginContext;
import com.reign.plugin.yx.common.BackstageUtil;
import com.reign.plugin.yx.common.IYxOperation;
import com.reign.plugin.yx.common.OpLogUtil;
import com.reign.plugin.yx.common.PingAnMoneyInfo;
import com.reign.plugin.yx.common.PingAnPlayerInfo;
import com.reign.plugin.yx.common.WebUtils;
import com.reign.plugin.yx.common.YxHelper;
import com.reign.plugin.yx.common.YxNoticeInfo;
import com.reign.plugin.yx.common.YxPlayerInfo;
import com.reign.plugin.yx.common.YxPlayerPayInfo;
import com.reign.plugin.yx.common.YxSourceInfo;
import com.reign.plugin.yx.common.YxTencentPayInfo;
import com.reign.plugin.yx.common.YxTencentUserInfo;
import com.reign.plugin.yx.common.YxUserInfo;
import com.reign.plugin.yx.util.Coder;
import com.reign.plugin.yx.util.HMAC_SHA1;
import com.reign.util.Tuple;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component("yxOperation")
/* loaded from: YxOperation.class */
public class YxOperation implements IYxOperation {

    @Autowired
    private IPlayerDao playerDao;

    @Autowired
    private IUserDao userDao;

    @Autowired
    private IPayService payService;

    @Autowired
    private IPlayerPayDao playerPayDao;

    @Autowired
    private ISilenceDao silenceDao;

    @Autowired
    private IUserBlockDao userBlockDao;

    @Autowired
    private ISystemNoticeDao systemNoticeDao;

    @Autowired
    private IPlayerResourceDao playerResourceDao;

    @Autowired
    private IPlayerTaobaoDao playerTaobaoDao;

    @Autowired
    private IActivityService activityService;

    @Autowired
    private IPlayerAttributeDao playerAttributeDao;
    private int TEN_YEARS_HOURS = 87600;
    public static final String yxPengyou = "pengyou";
    public static final String yxQzone = "qzone";
    public static final String yx3366 = "3366";
    private static final int WXIN_REWARD_NUMBER = 20000;
    private static final Logger errorLog = new ErrorLogger();
    private static final Log opReport = LogFactory.getLog("com.reign.gcld.opreport");
    private static Map<String, YxTencentPayInfo> tencentPayMap = new ConcurrentHashMap();

    public Session login(String yx, String userId, String userName, String sfid, String adult, String yxSource, Request request) {
        UserDto dto = new UserDto();
        dto.userId = userId;
        dto.userName = userName;
        dto.loginTime = System.currentTimeMillis();
        dto.yx = yx;
        dto.setYxSource(yxSource);
        dto.firstLogin = this.playerDao.getRoleCount(userId, yx) <= 0;
        if (this.userDao.getUserByUserName(userName) == null) {
            User user = new User();
            user.setUserName(userName);
            user.setAdult(1);
            user.setPassword(userId);
            user.setActivate(1);
            user.setActivateCode((String) null);
            user.setRewardForce(0);
            this.userDao.create(user);
        }
        if (WebUtil.needAntiAddiction(yx) && "0".equals(adult)) {
            dto.setNeedAntiAddiction(true);
        } else {
            dto.setNeedAntiAddiction(false);
        }
        Session session = request.getNewSession();
        session.setAttribute("user", dto);
        List<Player> players = this.playerDao.getPlayerNoDeleteByUserIdAndYx(userId, yx);
        if (players != null && players.size() > 0) {
            Player p = players.get(0);
            PlayerDto pdto = new PlayerDto();
            pdto.playerId = p.getPlayerId().intValue();
            pdto.playerName = p.getPlayerName();
            pdto.playerLv = p.getPlayerLv().intValue();
            pdto.loginTime = dto != null ? dto.loginTime : System.currentTimeMillis();
            pdto.userId = userId;
            pdto.yx = yx;
            pdto.forceId = p.getForceId().intValue();
            pdto.consumeLv = p.getConsumeLv().intValue();
            pdto.yxSource = p.getYxSource();
            PlayerAttribute pa = this.playerAttributeDao.read(p.getPlayerId().intValue());
            char[] cs = pa.getFunctionId().toCharArray();
            pdto.cs = cs;
            pdto.gm = p.getGm().intValue();
            session.setAttribute("PLAYER", pdto);
        }
        return session;
    }

    public Session loginForTencent(String yx, String adult, String yxSource, YxTencentUserInfo ytuInfo, Request request) {
        UserDto dto = new UserDto();
        dto.userId = ytuInfo.getUserId();
        dto.userName = ytuInfo.getUserName();
        dto.loginTime = System.currentTimeMillis();
        dto.yx = yx;
        dto.setYxSource(yxSource);
        dto.setOpenId(ytuInfo.getOpenId());
        dto.setOpenKey(ytuInfo.getOpenKey());
        dto.setIsYellowVip(ytuInfo.getIsYellowVip());
        dto.setYellowVipLevel(ytuInfo.getYellowVipLevel());
        dto.setIsYellowHighVip(ytuInfo.getIsYellowHighVip());
        dto.setIsYellowYearVip(ytuInfo.getIsYellowYearVip());
        dto.setPf(ytuInfo.getPf());
        dto.setPfKey(ytuInfo.getPfKey());
        dto.setUserIp(ytuInfo.getUserIp());
        dto.firstLogin = this.playerDao.getRoleCountByUid(dto.userId) <= 0;
        if (WebUtil.needAntiAddiction(yx) && "0".equals(adult)) {
            dto.setNeedAntiAddiction(true);
        } else {
            dto.setNeedAntiAddiction(false);
        }
        Session session = request.getNewSession();
        session.setAttribute("user", dto);
        return session;
    }

    public Tuple<Integer, Integer> pay(String orderId, int playerId, String userId, String yx, int gold, Request request) {
        Tuple<Integer, Integer> tuple = new Tuple<>();
        if (playerId <= 0) {
            playerId = getDefaultPayPlayer(userId, yx);
        }
        Player player = this.playerDao.read(playerId);
        if (player == null) {
            tuple.left = 2;
            tuple.right = 2;
            return tuple;
        }
        if (checkTencentPf(yx) && !player.getYx().equals(yx)) {
            yx = player.getYx();
        }
        if (!player.getUserId().equalsIgnoreCase(userId) || !player.getYx().equals(yx)) {
            tuple.left = 3;
            tuple.right = 3;
            return tuple;
        }
        try {
            Constants.locks[playerId % Constants.LOCKS_LEN].lock();
            if (this.playerPayDao.containsOrderId(orderId, yx)) {
                tuple.left = 5;
                tuple.right = 5;
                Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
                return tuple;
            }
            if (!this.payService.commonPay(orderId, gold, userId, yx, 0, "充值获得金币", player, new Date(), player.getYxSource(), request)) {
                tuple.left = 1000;
                tuple.right = 1000;
                Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
                return tuple;
            }
            Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
            try {
                this.payService.addAdditionalGold(playerId, gold);
            } catch (Exception var15) {
                errorLog.error("#pay_activity_error#orderId#" + orderId + "#playerId#" + playerId + "#userId#" + userId + "#gold#" + gold + "#");
                errorLog.error("#pay_activity_error#orderId#" + orderId + "#playerId#" + playerId + "#userId#" + userId + "#gold#" + gold + "#", var15);
            }
            try {
                this.payService.addTicketGold(playerId, gold);
            } catch (Exception var14) {
                errorLog.error("#pay_ticket_activity_error#orderId#" + orderId + "#playerId#" + playerId + "#userId#" + userId + "#gold#" + gold + "#");
                errorLog.error("#pay_ticket_activity_error#orderId#" + orderId + "#playerId#" + playerId + "#userId#" + userId + "#gold#" + gold + "#", var14);
            }
            tuple.left = 1;
            tuple.right = 1;
            return tuple;
        } catch (Throwable th) {
            Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
            throw th;
        }
    }

    public List<YxPlayerInfo> queryPlayer(String userId, String yx) {
        List<Player> players = this.playerDao.getPlayerNoDeleteByUserIdAndYx(userId, yx);
        List<YxPlayerInfo> playerList = new ArrayList<>();
        for (Player player : players) {
            YxPlayerInfo ypi = new YxPlayerInfo(player.getPlayerId().intValue(), player.getPlayerName(), player.getState().intValue(), player.getPlayerLv().intValue(), player.getForceId().intValue(), userId, player.getCreateTime());
            playerList.add(ypi);
        }
        return playerList;
    }

    public YxPlayerInfo queryPlayer(String userId, String yx, String playerName) {
        Player player = this.playerDao.queryPlayer(userId, yx, playerName);
        if (player == null) {
            return null;
        }
        YxPlayerInfo ypi = new YxPlayerInfo(player.getPlayerId().intValue(), player.getPlayerName(), player.getState().intValue(), player.getPlayerLv().intValue(), player.getForceId().intValue(), userId, player.getCreateTime());
        return ypi;
    }

    public YxPlayerInfo queryPlayerByPlayerNameAndYx(String playerName, String yx) {
        Player player = this.playerDao.getPlayerByNameAndYx(playerName, yx);
        if (player == null) {
            return null;
        }
        YxPlayerInfo ypi = new YxPlayerInfo(player.getPlayerId().intValue(), player.getPlayerName(), player.getState().intValue(), player.getPlayerLv().intValue(), player.getForceId().intValue(), player.getUserId(), player.getCreateTime());
        return ypi;
    }

    public List<YxPlayerPayInfo> queryPlayerPayDetails(String yx, String userId, int playerId) {
        List<YxPlayerPayInfo> playerPayList = new ArrayList<>();
        List<PlayerPay> payList = this.playerPayDao.getPlayerPayByPlayerId(playerId);
        for (PlayerPay p : payList) {
            if (p.getYx().equals(yx) && p.getUserId().equals(userId)) {
                YxPlayerPayInfo ppi = new YxPlayerPayInfo(userId, p.getOrderId(), p.getGold().intValue(), p.getType().intValue(), p.getCreateTime(), p.getPlayerId().intValue());
                playerPayList.add(ppi);
            }
        }
        return playerPayList;
    }

    public YxUserInfo getYxUserInfo(Request request) {
        Object obj = request.getSession().getAttribute("user");
        if (obj != null && (obj instanceof UserDto)) {
            UserDto dto = (UserDto) obj;
            return new YxUserInfo(dto.userId, dto.userName);
        }
        return null;
    }

    public YxPlayerInfo getYxPlayerInfo(Request request) {
        PlayerDto dto = Players.getSession(request.getSession().getId());
        if (dto == null) {
            return null;
        }
        return new YxPlayerInfo(dto.playerId, dto.playerName, 0, dto.playerLv, dto.forceId, dto.userId, dto.createTime);
    }

    public int getDefaultPayPlayer(String userId, String yx) {
        return this.playerDao.getDefaultPlayerId(userId, yx);
    }

    public YxPlayerInfo getDefaultPayPlayer(Request request) {
        Object obj = request.getSession().getAttribute("user");
        if (obj != null && (obj instanceof UserDto)) {
            UserDto dto = (UserDto) obj;
            int playerId = getDefaultPayPlayer(dto.userId, dto.yx);
            if (playerId <= 0) {
                return null;
            }
            Player player = this.playerDao.read(playerId);
            return new YxPlayerInfo(playerId, player.getPlayerName(), player.getState().intValue(), player.getPlayerLv().intValue(), player.getForceId().intValue(), player.getUserId(), player.getCreateTime());
        }
        return null;
    }

    public List<YxPlayerPayInfo> queryYxPayDetails(String yx, Date startTime, Date endTime) {
        List<YxPlayerPayInfo> playerPayList = new ArrayList<>();
        List<PlayerPay> payList = this.playerPayDao.getPlayerPayByDateAndYx(startTime, endTime, yx);
        for (PlayerPay p : payList) {
            YxPlayerPayInfo ppi = new YxPlayerPayInfo(p.getUserId(), p.getOrderId(), p.getGold().intValue(), p.getType().intValue(), p.getCreateTime(), p.getPlayerId().intValue());
            playerPayList.add(ppi);
        }
        return playerPayList;
    }

    public List<YxSourceInfo> queryPlayerYxSource(String yx, Date date, int page, int size) {
        List<Player> playerList = this.playerDao.getPlayerList(yx, date, page, size);
        if (playerList != null && playerList.size() > 0) {
            List<YxSourceInfo> yxSourceInfoList = new ArrayList<>();
            for (Player player : playerList) {
                yxSourceInfoList.add(new YxSourceInfo(player.getUserId(), player.getPlayerId().intValue(), player.getPlayerName(), player.getPlayerLv().intValue(), player.getLoginTime()));
            }
            return yxSourceInfoList;
        }
        return new ArrayList();
    }

    public int queryPlayerYxSourceSize(String yx, Date date) {
        return this.playerDao.getSizeByYxAndDate(yx, date);
    }

    public int getOnlinePlayersNumber(String yx) {
        return Players.getOnlinePlayersNumber(yx);
    }

    public YxPlayerInfo getPlayerById(int playerId) {
        Player player = this.playerDao.read(playerId);
        if (player == null) {
            return null;
        }
        return new YxPlayerInfo(playerId, player.getPlayerName(), player.getState().intValue(), player.getPlayerLv().intValue(), player.getForceId().intValue(), player.getUserId(), player.getCreateTime());
    }

    public int getDailyOnlineTime(int playerId) {
        int result = this.playerDao.getDailyOnlineTime(playerId);
        PlayerDto dto = Players.getPlayer(playerId);
        if (dto != null) {
            result += (int) ((System.currentTimeMillis() - dto.loginTime) / 1000);
        }
        return result;
    }

    public YxPlayerPayInfo queryOrder(String orderId, String yx) {
        PlayerPay p = this.playerPayDao.queryOrder(orderId, yx);
        if (p == null) {
            return null;
        }
        return new YxPlayerPayInfo(p.getUserId(), p.getOrderId(), p.getGold().intValue(), p.getType().intValue(), p.getCreateTime(), p.getPlayerId().intValue());
    }

    public List<YxPlayerPayInfo> queryOrderByDateAndPage(Date startTime, Date endTime, int page, int size, String yx) {
        List<PlayerPay> ppList = this.playerPayDao.getPlayerPayByDateAndPage(startTime, endTime, (page - 1) * size, size, yx);
        if (ppList == null) {
            return null;
        }
        List<YxPlayerPayInfo> ppiList = new ArrayList<>();
        for (PlayerPay p : ppList) {
            ppiList.add(new YxPlayerPayInfo(p.getUserId(), p.getOrderId(), p.getGold().intValue(), p.getType().intValue(), p.getCreateTime(), p.getPlayerId().intValue()));
        }
        return ppiList;
    }

    public boolean banChat(String userIds, int keepTime, String yx) {
        boolean result = false;
        String[] userIdArr = userIds.split(",");
        Date nextSayTime = TimeUtil.nowAddMinutes(keepTime);
        Date nowDate = new Date();
        for (String userId : userIdArr) {
            List<Player> playerList = this.playerDao.getPlayerByUserId(userId, yx);
            for (Player player : playerList) {
                int playerId = player.getPlayerId().intValue();
                Silence silence = this.silenceDao.getByPlayerId(playerId);
                if (silence != null) {
                    silence.setNextSayTime(nextSayTime);
                    silence.setSilenceTime(nowDate);
                    silence.setReason("");
                    silence.setType(1);
                    this.silenceDao.update(silence);
                } else {
                    Silence silence2 = new Silence();
                    silence2.setNextSayTime(nextSayTime);
                    silence2.setPlayerId(Integer.valueOf(playerId));
                    silence2.setReason("");
                    silence2.setSilenceTime(nowDate);
                    silence2.setUserId(player.getUserId());
                    silence2.setYx(yx);
                    silence2.setType(1);
                    this.silenceDao.create(silence2);
                }
                result = true;
            }
        }
        return result;
    }

    public boolean unbanChat(String userIds, String yx) {
        boolean result = false;
        String[] userIdArr = userIds.split(",");
        Date nowDate = new Date();
        for (String userId : userIdArr) {
            List<Player> playerList = this.playerDao.getPlayerByUserId(userId, yx);
            for (Player player : playerList) {
                int playerId = player.getPlayerId().intValue();
                Silence silence = this.silenceDao.getByPlayerId(playerId);
                if (silence.getType().intValue() != 2) {
                    silence.setNextSayTime(nowDate);
                    this.silenceDao.update(silence);
                    result = true;
                }
            }
        }
        return result;
    }

    public boolean banUser(String userIds, String yx) {
        boolean result = false;
        Date endDate = TimeUtil.nowAddHours(this.TEN_YEARS_HOURS);
        String[] userIdArr = userIds.split(",");
        for (String userId : userIdArr) {
            List<Player> playerList = this.playerDao.getPlayerByUserId(userId, yx);
            for (Player player : playerList) {
                List<UserBlock> ubList = this.userBlockDao.getUserBlock(player.getUserId(), yx);
                if (ubList != null && ubList.size() > 0) {
                    Iterator var13 = ubList.iterator();
                    while (var13.hasNext()) {
                        this.userBlockDao.update(var13.next().getVId().intValue(), "", endDate);
                    }
                } else {
                    UserBlock ub = new UserBlock();
                    ub.setBlockEndTime(endDate);
                    ub.setPlayerId(player.getPlayerId());
                    ub.setUserId(player.getUserId());
                    ub.setYx(yx);
                    ub.setReason("");
                    this.userBlockDao.create(ub);
                }
                result = true;
                AuthInterceptor.blockPlayer(player.getUserId(), yx, endDate.getTime(), "");
            }
        }
        return result;
    }

    public boolean unbanUser(String userIds, String yx) {
        boolean result = false;
        String[] userIdArr = userIds.split(",");
        for (String userId : userIdArr) {
            List<Player> playerList = this.playerDao.getPlayerByUserId(userId, yx);
            for (Player player : playerList) {
                List<UserBlock> ubList = this.userBlockDao.getUserBlock(player.getUserId(), yx);
                if (ubList != null) {
                    for (UserBlock ub : ubList) {
                        if (ub.getPlayerId() == player.getPlayerId()) {
                            this.userBlockDao.deleteById(ub.getVId().intValue());
                            AuthInterceptor.unblockPlayer(player.getUserId(), yx);
                            result = true;
                        }
                    }
                }
            }
        }
        return result;
    }

    public List<YxNoticeInfo> queryNotice(String yx) {
        List<SystemNotice> list = this.systemNoticeDao.getModels();
        List<YxNoticeInfo> ynList = new ArrayList<>();
        Date now = new Date();
        for (SystemNotice sn : list) {
            if (sn.getYx().equalsIgnoreCase(yx) && sn.getStartTime().before(now) && sn.getExpireTime().after(now)) {
                ynList.add(new YxNoticeInfo(sn.getContent()));
            }
        }
        return ynList;
    }

    public Tuple<Boolean, Integer> modifyUserId(String yx, String oldUserId, String newUserId) {
        Tuple<Boolean, Integer> tuple = new Tuple<>();
        tuple.left = false;
        List<Player> oldList = this.playerDao.getPlayerByUserId(oldUserId, yx);
        if (oldList.size() < 1) {
            tuple.right = 1011;
            return tuple;
        }
        this.playerDao.modifyUserId(yx, oldUserId, newUserId);
        for (Player player : oldList) {
            int playerId = player.getPlayerId().intValue();
            PlayerDto dto = (PlayerDto) Players.playerMap.get(Integer.valueOf(playerId));
            if (dto != null) {
                dto.userId = newUserId;
            }
            for (PlayerDto playerDto : Players.sessionPlayerMap.values()) {
                if (playerDto.playerId == playerId) {
                    playerDto.userId = newUserId;
                }
            }
        }
        String oldId = String.valueOf(oldUserId) + "-" + yx;
        String newId = String.valueOf(newUserId) + "-" + yx;
        UserDto userDto1 = (UserDto) Users.userMap.remove(oldId);
        if (userDto1 != null) {
            userDto1.userId = newUserId;
            userDto1.setId(newId);
            Users.userMap.put(newId, userDto1);
        }
        Session session = (Session) Users.userSessionMap.remove(oldId);
        if (session != null) {
            Users.userSessionMap.put(newId, session);
        }
        UserDto userDto2 = (UserDto) Users.sessionUserMap.remove(oldId);
        if (userDto2 != null) {
            userDto2.userId = newUserId;
            userDto2.setId(newId);
            Users.sessionUserMap.put(newId, userDto2);
        }
        tuple.left = true;
        return tuple;
    }

    public boolean checkEmptyParams(Map<String, String> map, Request request, String yx) {
        long start = System.currentTimeMillis();
        for (String key : map.keySet()) {
            String value = map.get(key);
            if (StringUtils.isBlank(value)) {
                opReport.info(OpLogUtil.formatOpInterfaceLog("yx" + yx, "yx" + yx + "_fail_" + key + "_IS_EMPTY", YxHelper.getIp(request), request.getParamterMap(), request.getContent(), false, System.currentTimeMillis() - start, new ByteResult(BackstageUtil.returnError(1100)), 1100));
                return true;
            }
        }
        return false;
    }

    public String exeTencentQuery(String yx, Map<String, Object> paramMap, String baseUrl, String uri, String method, boolean isHttps, boolean isCallBack) {
        opReport.error("#start executing.....");
        String appKey = PluginContext.configuration.getTencentAppKey(yx);
        String sig = getOpenAPISign(uri, paramMap, appKey, method, isCallBack);
        paramMap.put("sig", sig);
        opReport.error("#sign:" + sig);
        String echo = "";
        try {
            String requestURL = WebUtils.getURL(String.valueOf(baseUrl) + uri, paramMap).replace("*", "%2A");
            opReport.error("query URL:" + requestURL);
            if (isHttps) {
                echo = WebUtils.sendSSLGetRequest(requestURL, paramMap);
            } else {
                echo = WebUtils.sendRequest(requestURL, paramMap);
            }
        } catch (UnsupportedEncodingException var12) {
            var12.printStackTrace();
            opReport.error("#YxOperation#exeTencentQuery#UnsupportedEncodingException:" + echo);
        }
        opReport.error("echo:" + echo);
        return echo;
    }

    public String getOpenAPISign(String uri, Map<String, Object> paramMap, String appkey, String method, boolean isCallBack) {
        List<String> keyList = new ArrayList<>(paramMap.keySet());
        Collections.sort(keyList);
        StringBuffer sb = new StringBuffer();
        for (String key : keyList) {
            if (!key.equals("sig")) {
                if (sb.length() > 0) {
                    sb.append("&");
                }
                sb.append(key);
                sb.append("=");
                if (isCallBack && key.equals("billno")) {
                    String value = paramMap.get(key).toString();
                    char[] charArray = value.toCharArray();
                    for (char asciiIntForV : charArray) {
                        if ((asciiIntForV < '0' || asciiIntForV > '9') && asciiIntForV != '!' && ((asciiIntForV < '(' || asciiIntForV > '*') && ((asciiIntForV < 'A' || asciiIntForV > 'Z') && (asciiIntForV < 'a' || asciiIntForV > 'z')))) {
                            String asciiForV = Integer.toHexString(asciiIntForV).toUpperCase();
                            sb.append("%");
                            sb.append(asciiForV);
                        } else {
                            sb.append(asciiIntForV);
                        }
                    }
                } else {
                    sb.append(paramMap.get(key));
                }
            }
        }
        if (method == null || method.isEmpty()) {
            method = "POST";
        }
        try {
            String key2 = String.valueOf(String.valueOf(method) + "&") + URLEncoder.encode(uri, "UTF-8") + "&" + URLEncoder.encode(sb.toString(), "UTF-8");
            opReport.error("source:" + key2);
            try {
                return Coder.encryptBASE64(HMAC_SHA1.getHmacSHA1(key2.replace("*", "%2A"), String.valueOf(appkey) + "&")).trim();
            } catch (Exception var16) {
                var16.printStackTrace();
                return null;
            }
        } catch (UnsupportedEncodingException var17) {
            var17.printStackTrace();
            return null;
        }
    }

    public void setTencentPayMap(Map<String, YxTencentPayInfo> tencentPayMap2) {
        tencentPayMap = tencentPayMap2;
    }

    public Map<String, YxTencentPayInfo> getTencentPayMap() {
        return tencentPayMap;
    }

    public void removeTencentPayMap(String key) {
        tencentPayMap.remove(key);
    }

    public boolean checkTencentPf(String pf) {
        String pf2 = pf.replace("_m", "");
        return pf2.equals(yxPengyou) || pf2.equals(yxQzone) || pf2.equals(yx3366);
    }

    public Tuple<Integer, Integer> rewardWX(int playerId, String userId, String yx) {
        Tuple<Integer, Integer> tuple = new Tuple<>();
        if (playerId <= 0) {
            playerId = getDefaultPayPlayer(userId, yx);
        }
        Player player = this.playerDao.read(playerId);
        if (player == null) {
            tuple.left = 2;
            tuple.right = 2;
            return tuple;
        }
        if (player.getUserId().equalsIgnoreCase(userId)) {
            try {
                if (player.getYx().equals(yx)) {
                    try {
                        Constants.locks[playerId % Constants.LOCKS_LEN].lock();
                    } catch (Exception var11) {
                        errorLog.error(this, var11);
                        Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
                    }
                    if (this.playerTaobaoDao.read(player.getPlayerId().intValue()) == null) {
                        PlayerTaobao playerTaobao = new PlayerTaobao();
                        playerTaobao.setPlayerId(player.getPlayerId());
                        this.playerTaobaoDao.create(playerTaobao);
                        Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
                        this.playerResourceDao.addCopperIgnoreMax(playerId, 20000.0d, "旺信大礼包获取银币", false);
                        this.playerResourceDao.addFoodIgnoreMax(playerId, 20000.0d, "旺信大礼包获取粮食");
                        this.playerResourceDao.addWoodIgnoreMax(playerId, 20000.0d, "旺信大礼包获取木材", false);
                        tuple.left = 1;
                        tuple.right = 1;
                        return tuple;
                    }
                    tuple.left = 5;
                    tuple.right = 5;
                    Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
                    return tuple;
                }
            } catch (Throwable th) {
                Constants.locks[playerId % Constants.LOCKS_LEN].unlock();
                throw th;
            }
        }
        tuple.left = 3;
        tuple.right = 3;
        return tuple;
    }

    public int getAllPlayerNumber() {
        return this.playerDao.getModelSize();
    }

    public List<PingAnPlayerInfo> queryPlayerInfo(String customer, String yx, String gatewayId) {
        List<Player> playerList = this.playerDao.getPlayerNoDeleteByUserIdAndYx(customer, yx);
        List<PingAnPlayerInfo> result = new ArrayList<>();
        for (Player cell : playerList) {
            PingAnPlayerInfo info = new PingAnPlayerInfo();
            info.roleName = cell.getPlayerName();
            info.roleLever = "" + cell.getPlayerLv();
            info.roleServer = gatewayId;
            info.roleCoin = "" + cell.getSysGold();
            result.add(info);
        }
        return result;
    }

    public PingAnMoneyInfo queryMoneyInfo(String customer, String yx) {
        List<Player> players = this.playerDao.getPlayerByUserId(customer, yx);
        int sum = 0;
        for (Player player : players) {
            sum += player.getSysGold().intValue();
        }
        PingAnMoneyInfo info = new PingAnMoneyInfo();
        info.avaliableGameAmount = String.valueOf(sum);
        return info;
    }

    public int test360Privilege(String uId, int level) {
        return this.activityService.recv360PrivilegeForTest(uId, level);
    }
}
